==> openjdk-19_19~23ea.orig.tar.xz: openjdk-19-19~23ea/test/hotspot/jtreg/serviceability/jvmti/thread/GetFrameLocation/frameloc02/frameloc02.java <==
/*
 * Copyright (c) 2003, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * @test
 *
 * @summary converted from VM Testbase nsk/jvmti/GetFrameLocation/frameloc002.
 * VM Testbase keywords: [quick, jpda, jvmti, noras]
 * VM Testbase readme:
 * DESCRIPTION
 *     The test exercises JVMTI function GetFrameLocation.
 *     The test checks if the function returns expected values
 *     for a native (JNI) frame.
 * COMMENTS
 *     Fixed according to 4802866 bug.
 *     Ported from JVMDI.
 *     Fixed the 5004632 bug.
 *
 * @library /test/lib
 * @run main/othervm/native -agentlib:frameloc02 frameloc02
 */

import java.io.PrintStream;

public class frameloc02 {

    final static int JCK_STATUS_BASE = 95;

    static {
        try {
            System.loadLibrary("frameloc02");
        } catch (UnsatisfiedLinkError ule) {
            System.err.println("Could not load frameloc02 library");
            System.err.println("java.library.path:"
                + System.getProperty("java.library.path"));
            throw ule;
        }
    }

    native static int check(Thread thr);

    public static void main(String args[]) {
        // produce JCK-like exit status.
        System.exit(run(args, System.out) + JCK_STATUS_BASE);
    }

    public static int run(String args[], PrintStream out) {
        return check(Thread.currentThread());
    }
}

==> openjdk-24_24~29ea.orig.tar.xz: openjdk-24-24~29ea/test/hotspot/jtreg/serviceability/jvmti/thread/GetFrameLocation/frameloc02/frameloc02.java <==
/*
 * Copyright (c) 2003, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * @test
 *
 * @summary converted from VM Testbase nsk/jvmti/GetFrameLocation/frameloc002.
 * VM Testbase keywords: [quick, jpda, jvmti, noras]
 * VM Testbase readme:
 * DESCRIPTION
 *     The test exercises JVMTI function GetFrameLocation.
 *     The test checks if the function returns expected values
 *     for a native (JNI) frame.
 * COMMENTS
 *     Fixed according to 4802866 bug.
 *     Ported from JVMDI.
 *     Fixed the 5004632 bug.
 *
 * @library /test/lib
 * @run main/othervm/native -agentlib:frameloc02 frameloc02
 */

public class frameloc02 {

    static {
        System.loadLibrary("frameloc02");
    }

    native static int check(Thread thr);

    public static void main(String args[]) {
        int result = check(Thread.currentThread());
        if (result != 0) {
            throw new RuntimeException("check failed with result " + result);
        }
    }
}
